<no title> — CALCEPH - Octave/Matlab language 3.4.1 documentation

    jd0=2442457
    dt=0.5E0

    peph = CalcephBin.open('example1.dat');

    % compute only the heliocentric position of Mars in km
    P = peph.compute_order(jd0, dt, NaifId.MARS_BARYCENTER, NaifId.SUN,
                            Constants.UNIT_KM+Constants.UNIT_SEC+Constants.USE_NAIFID, 0)

    % compute positions, velocities, accelerations and jerks of Mars in km and seconds
    PVAJ = peph.compute_order(jd0, dt, NaifId.MARS_BARYCENTER, NaifId.SUN,
                            Constants.UNIT_KM+Constants.UNIT_SEC+Constants.USE_NAIFID, 3)

    peph.close();